package query

import (
	"encoding/json"
	"github.com/odysseus/service-registry/common"
	"github.com/redis/go-redis/v9"
)

type WorkerInfo struct {
	Timestamp      int64    `json:"timestamp"`
	HearBeat       int64    `json:"heartbeat"`
	ActiveNM       []string `json:"active_nm"`
	MinerAddress   string   `json:"miner_address"`
	BenefitAddress string   `json:"benefit_address"`
	IPs            []string `json:"ip_list"`
	Status         string   `json:"status"`
}

func (g WorkerInfo) TimeStamp() int64 {
	return g.Timestamp
}

func (g WorkerInfo) Message() json.RawMessage {
	d, _ := json.Marshal(g)
	return d
}

func (g WorkerInfo) Parse(res *redis.MapStringStringCmd) ServiceInfo {
	var info WorkerInfo
	if err := res.Scan(&info); err != nil {
		return nil
	}
	return info
}

type workerQuery struct {
	baseService
}

func getWorkerQuery(rdb *redis.Client) ServiceQuery {
	return workerQuery{
		baseService{
			rdb:     rdb,
			service: common.SERVICE_WORKER,
		},
	}
}
